@@ -1,52 +1,67 @@
+//! Ockam is a library for building devices that communicate securely, privately
+//! and trustfully with cloud services and other devices.
+#![deny(
+  //  missing_docs, // not compatible with big_array
+    trivial_casts,
+    trivial_numeric_casts,
+    unsafe_code,
+    unused_import_braces,
+    unused_qualifications,
+    // TODO restore before merge warnings
+)]
 // ---
 // #![no_std] if the standard library is not present.
-
 #![cfg_attr(not(feature = "std"), no_std)]
 
 #[macro_use]
 extern crate serde_big_array;
 
+#[macro_use]
+extern crate tracing;
+
 big_array! { BigArray; 96 }
 
 // ---
 // Export the #[node] attribute macro.
-
 pub use ockam_node_attribute::*;
-
 // ---
-// Export node implementation
 
+// Export node implementation
 #[cfg(all(feature = "std", feature = "ockam_node"))]
 pub use ockam_node::*;
 
 #[cfg(all(not(feature = "std"), feature = "ockam_node_no_std"))]
 pub use ockam_node_no_std::*;
-
 // ---
 
-mod profile;
-pub use profile::*;
-mod error;
-pub use error::*;
 mod credential;
+mod error;
 mod lease;
+mod protocols;
+mod remote_forwarder;
 
 pub use credential::*;
+pub use error::*;
 pub use lease::*;
-
-mod remote_forwarder;
+pub use ockam_core::worker;
+pub use ockam_entity::*;
 pub use remote_forwarder::*;
 
-pub use ockam_core::worker;
 pub use ockam_core::{
-    Address, Any, Encoded, Error, Message, Result, Route, Routed, RouterMessage, TransportMessage,
-    Worker,
+    Address, Any, Encoded, Error, Message, ProtocolId, Result, Route, Routed, RouterMessage,
+    TransportMessage, Worker,
 };
 
-pub use ockam_vault_sync_core::Vault;
-
 pub use ockam_channel::SecureChannel;
 
+pub use ockam_key_exchange_core::NewKeyExchanger;
+
+#[cfg(feature = "noise_xx")]
+pub use ockam_key_exchange_xx::XXNewKeyExchanger;
+
+#[cfg(feature = "ockam_vault")]
+pub use ockam_vault_sync_core::{Vault, VaultSync};
+
 #[cfg(feature = "ockam_vault")]
 pub use ockam_vault::SoftwareVault;
 
