@@ -1,3 +1,5 @@
+#![deny(missing_docs)]
+
 use crate::{Context, OckamError};
 use ockam_core::lib::net::SocketAddr;
 use ockam_core::{Address, Any, Result, Route, Routed, TransportMessage, Worker};
@@ -5,6 +7,7 @@ use rand::random;
 use serde::{Deserialize, Serialize};
 use tracing::{debug, info};
 
+/// Information about a remotely forwarded worker.
 #[derive(Serialize, Deserialize, Clone, PartialEq, Debug)]
 pub struct RemoteForwarderInfo {
     forwarding_route: Route,
@@ -13,12 +16,15 @@ pub struct RemoteForwarderInfo {
 }
 
 impl RemoteForwarderInfo {
+    /// Returns the forwarding route.
     pub fn forwarding_route(&self) -> &Route {
         &self.forwarding_route
     }
+    /// Returns the remote address.
     pub fn remote_address(&self) -> &str {
         &self.remote_address
     }
+    /// Returns the worker address.
     pub fn worker_address(&self) -> &Address {
         &self.worker_address
     }
@@ -48,18 +54,24 @@ impl RemoteForwarder {
     /// Create and start new RemoteForwarder with given Ockam Hub address
     /// and Address of destination Worker that should receive forwarded messages
     pub async fn create<A: Into<Address>, S: Into<String>>(
-        ctx: &mut Context,
+        ctx: &Context,
         hub_addr: S,
         destination: A,
     ) -> Result<RemoteForwarderInfo> {
         if let Ok(hub_addr) = hub_addr.into().parse::<SocketAddr>() {
-            let forwarder = Self::new(hub_addr, destination.into(), ctx.address());
+            let address: Address = random();
+            let mut child_ctx = ctx.new_context(address).await?;
+            let forwarder = Self::new(hub_addr, destination.into(), child_ctx.address());
 
             let worker_address: Address = random();
             debug!("Starting RemoteForwarder at {}", &worker_address);
             ctx.start_worker(worker_address, forwarder).await?;
 
-            let resp = ctx.receive::<RemoteForwarderInfo>().await?.take().body();
+            let resp = child_ctx
+                .receive::<RemoteForwarderInfo>()
+                .await?
+                .take()
+                .body();
 
             Ok(resp)
         } else {
@@ -73,7 +85,7 @@ impl Worker for RemoteForwarder {
     type Context = Context;
     type Message = Any;
 
-    async fn initialize(&mut self, ctx: &mut Self::Context) -> crate::Result<()> {
+    async fn initialize(&mut self, ctx: &mut Self::Context) -> Result<()> {
         debug!("RemoteForwarder registering...");
         ctx.send(self.route.clone(), "register".to_string()).await?;
         let resp = ctx.receive::<String>().await?.take();
